--[[
Author: Starinnia
CPR is a combo points display addon based on Funkydude's BasicComboPoints
Poison.lua - A module for tracking deadly poison stacks
$Date: 2010-07-22 22:51:38 +0000 (Thu, 22 Jul 2010) $
$Revision: 103 $
Project Version: r103
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2010 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

local cpr = LibStub("AceAddon-3.0"):GetAddon("ComboPointsRedux")
local modName = "Deadly Poison"
local Poison = cpr:NewModule(modName, "AceConsole-3.0", "AceEvent-3.0")
local LSM = LibStub("LibSharedMedia-3.0")
Poison.abbrev = "DP"
local UnitAura = UnitAura
local strfind = string.find


function Poison:OnInitialize()
	self.graphics = cpr:MakeGraphicsFrame(modName)
	self.text = cpr:MakeTextFrame(modName)
end

function Poison:OnEnable()
	if not cpr.db.profile.modules[modName].disableGraphics then
		self.graphics:Show()
	end
	if not cpr.db.profile.modules[modName].disableText then
		self.text:Show()
	end
	
	self:RegisterEvent("UNIT_AURA")
	self:RegisterEvent("PLAYER_TARGET_CHANGED")
end

function Poison:OnDisable()
	self.graphics:Hide()
	self.text:Hide()
	self:UnregisterEvent("UNIT_AURA")
	self:UnregisterEvent("PLAYER_TARGET_CHANGED")
end

local function getPoisonStack()
	local icon, count, _
	local i = 1
	
	if UnitExists("target") then
		while UnitAura("target", i, nil, "PLAYER|HARMFUL") ~= nil do
			_, _, icon, count = UnitAura("target", i, nil, "PLAYER|HARMFUL")
			if strfind(icon, "Ability_Rogue_DualWeild") then
				return count
			end
			i = i + 1
		end
	end
	
	return 0
end

function Poison:UNIT_AURA(event, unit)
	if unit ~= "target" then return end
	
	if UnitIsDead("target") then
		self:UpdateDeadlyPoison(0)
		return
	end
		
	self:UpdateDeadlyPoison(getPoisonStack())
end

function Poison:PLAYER_TARGET_CHANGED()
	if UnitIsDead("target") then
		self:UpdateDeadlyPoison(0)
		return
	end
	
	self:UpdateDeadlyPoison(getPoisonStack())
end

function Poison:UpdateDeadlyPoison(stacks)
	local r, g, b = cpr:GetColorByPoints(modName, stacks)
	
	if stacks == 0 then
		for i = 1, 5 do
			self.graphics.points[i]:Hide()
		end
		stacks = ""
	elseif stacks == 5 then
		for i = stacks, 1, -1 do
			self.graphics.points[i].icon:SetVertexColor(r, g, b)
			self.graphics.points[i]:Show()
		end
	else
		for i = stacks, 1, -1 do
			self.graphics.points[i].icon:SetVertexColor(r, g, b)
			self.graphics.points[i]:Show()
		end
		for j = 5, stacks+1, -1 do
			self.graphics.points[j]:Hide()
		end
	end
	
	self.text:SetNumPoints(stacks)
end

--Set handler for the module options
function Poison:Set(info, ...)
	if info.type == "color" then
		local color = cpr.db.profile.modules[modName][info.arg]
		color[1], color[2], color[3] = ...
	else
		cpr.db.profile.modules[modName][info.arg] = ...
	end
	cpr:UpdateSettings(modName)
end

--Get handler for the module options
function Poison:Get(info, ...)
	if info.type == "color" then
		return unpack(cpr.db.profile.modules[modName][info.arg])
	else
		return cpr.db.profile.modules[modName][info.arg]
	end
end
